@@ -11,8 +11,8 @@ from fastapi.utils import get_flat_models_from_routes, get_model_definitions
 from pydantic.fields import Field
 from pydantic.schema import Schema, field_schema, get_model_name_map
 from pydantic.utils import lenient_issubclass
-from starlette.responses import HTMLResponse, JSONResponse
-from starlette.routing import BaseRoute, Route
+from starlette.responses import JSONResponse
+from starlette.routing import BaseRoute
 from starlette.status import HTTP_422_UNPROCESSABLE_ENTITY
 
 validation_error_definition = {
@@ -124,7 +124,7 @@ def generate_operation_id(*, route: routing.APIRoute, method: str) -> str:
 def generate_operation_summary(*, route: routing.APIRoute, method: str) -> str:
     if route.summary:
         return route.summary
-    return method.title() + " " + route.name.replace("_", " ").title()
+    return route.name.replace("_", " ").title() + " " + method.title()
 
 
 def get_openapi_operation_metadata(*, route: routing.APIRoute, method: str) -> Dict:
@@ -172,6 +172,11 @@ def get_openapi_path(
             )
             if request_body_oai:
                 operation["requestBody"] = request_body_oai
+                if "ValidationError" not in definitions:
+                    definitions["ValidationError"] = validation_error_definition
+                    definitions[
+                        "HTTPValidationError"
+                    ] = validation_error_response_definition
         status_code = str(route.status_code)
         response_schema = {"type": "string"}
         if lenient_issubclass(route.content_type, JSONResponse):
