@@ -51,7 +51,8 @@ def get_app(
         try:
             body = None
             if body_field:
-                if is_body_form:
+                body_bytes = await request.body()
+                if body_bytes and is_body_form:
                     raw_body = await request.form()
                     body = {}
                     for field, value in raw_body.items():
@@ -59,20 +60,16 @@ def get_app(
                             body[field] = await value.read()
                         else:
                             body[field] = value
-                else:
+                elif body_bytes:
                     body = await request.json()
         except Exception as e:
             logging.error("Error getting request body", e)
             raise HTTPException(
                 status_code=400, detail="There was an error parsing the body"
             )
-        try:
-            values, errors = await solve_dependencies(
-                request=request, dependant=dependant, body=body
-            )
-        except Exception as e:
-            logging.error("Error solving dependencies", e)
-            raise HTTPException(status_code=400, detail="Error processing request")
+        values, errors = await solve_dependencies(
+            request=request, dependant=dependant, body=body
+        )
         if errors:
             errors_out = ValidationError(errors)
             raise HTTPException(
@@ -209,11 +206,11 @@ class APIRouter(routing.Router):
         description: str = None,
         response_description: str = "Successful Response",
         deprecated: bool = None,
-        name: str = None,
         methods: List[str] = None,
         operation_id: str = None,
         include_in_schema: bool = True,
         content_type: Type[Response] = JSONResponse,
+        name: str = None,
     ) -> None:
         route = APIRoute(
             path,
@@ -225,11 +222,11 @@ class APIRouter(routing.Router):
             description=description,
             response_description=response_description,
             deprecated=deprecated,
-            name=name,
             methods=methods,
             operation_id=operation_id,
             include_in_schema=include_in_schema,
             content_type=content_type,
+            name=name,
         )
         self.routes.append(route)
 
@@ -244,11 +241,11 @@ class APIRouter(routing.Router):
         description: str = None,
         response_description: str = "Successful Response",
         deprecated: bool = None,
-        name: str = None,
         methods: List[str] = None,
         operation_id: str = None,
         include_in_schema: bool = True,
         content_type: Type[Response] = JSONResponse,
+        name: str = None,
     ) -> Callable:
         def decorator(func: Callable) -> Callable:
             self.add_api_route(
@@ -261,11 +258,11 @@ class APIRouter(routing.Router):
                 description=description,
                 response_description=response_description,
                 deprecated=deprecated,
-                name=name,
                 methods=methods,
                 operation_id=operation_id,
                 include_in_schema=include_in_schema,
                 content_type=content_type,
+                name=name,
             )
             return func
 
@@ -289,19 +286,19 @@ class APIRouter(routing.Router):
                     description=route.description,
                     response_description=route.response_description,
                     deprecated=route.deprecated,
-                    name=route.name,
                     methods=route.methods,
                     operation_id=route.operation_id,
                     include_in_schema=route.include_in_schema,
                     content_type=route.content_type,
+                    name=route.name,
                 )
             elif isinstance(route, routing.Route):
                 self.add_route(
                     prefix + route.path,
                     route.endpoint,
                     methods=route.methods,
-                    name=route.name,
                     include_in_schema=route.include_in_schema,
+                    name=route.name,
                 )
 
     def get(
@@ -315,10 +312,10 @@ class APIRouter(routing.Router):
         description: str = None,
         response_description: str = "Successful Response",
         deprecated: bool = None,
-        name: str = None,
         operation_id: str = None,
         include_in_schema: bool = True,
         content_type: Type[Response] = JSONResponse,
+        name: str = None,
     ) -> Callable:
         return self.api_route(
             path=path,
@@ -329,11 +326,11 @@ class APIRouter(routing.Router):
             description=description,
             response_description=response_description,
             deprecated=deprecated,
-            name=name,
             methods=["GET"],
             operation_id=operation_id,
             include_in_schema=include_in_schema,
             content_type=content_type,
+            name=name,
         )
 
     def put(
@@ -347,10 +344,10 @@ class APIRouter(routing.Router):
         description: str = None,
         response_description: str = "Successful Response",
         deprecated: bool = None,
-        name: str = None,
         operation_id: str = None,
         include_in_schema: bool = True,
         content_type: Type[Response] = JSONResponse,
+        name: str = None,
     ) -> Callable:
         return self.api_route(
             path=path,
@@ -361,11 +358,11 @@ class APIRouter(routing.Router):
             description=description,
             response_description=response_description,
             deprecated=deprecated,
-            name=name,
             methods=["PUT"],
             operation_id=operation_id,
             include_in_schema=include_in_schema,
             content_type=content_type,
+            name=name,
         )
 
     def post(
@@ -379,10 +376,10 @@ class APIRouter(routing.Router):
         description: str = None,
         response_description: str = "Successful Response",
         deprecated: bool = None,
-        name: str = None,
         operation_id: str = None,
         include_in_schema: bool = True,
         content_type: Type[Response] = JSONResponse,
+        name: str = None,
     ) -> Callable:
         return self.api_route(
             path=path,
@@ -393,11 +390,11 @@ class APIRouter(routing.Router):
             description=description,
             response_description=response_description,
             deprecated=deprecated,
-            name=name,
             methods=["POST"],
             operation_id=operation_id,
             include_in_schema=include_in_schema,
             content_type=content_type,
+            name=name,
         )
 
     def delete(
@@ -411,10 +408,10 @@ class APIRouter(routing.Router):
         description: str = None,
         response_description: str = "Successful Response",
         deprecated: bool = None,
-        name: str = None,
         operation_id: str = None,
         include_in_schema: bool = True,
         content_type: Type[Response] = JSONResponse,
+        name: str = None,
     ) -> Callable:
         return self.api_route(
             path=path,
@@ -425,11 +422,11 @@ class APIRouter(routing.Router):
             description=description,
             response_description=response_description,
             deprecated=deprecated,
-            name=name,
             methods=["DELETE"],
             operation_id=operation_id,
             include_in_schema=include_in_schema,
             content_type=content_type,
+            name=name,
         )
 
     def options(
@@ -443,10 +440,10 @@ class APIRouter(routing.Router):
         description: str = None,
         response_description: str = "Successful Response",
         deprecated: bool = None,
-        name: str = None,
         operation_id: str = None,
         include_in_schema: bool = True,
         content_type: Type[Response] = JSONResponse,
+        name: str = None,
     ) -> Callable:
         return self.api_route(
             path=path,
@@ -457,11 +454,11 @@ class APIRouter(routing.Router):
             description=description,
             response_description=response_description,
             deprecated=deprecated,
-            name=name,
             methods=["OPTIONS"],
             operation_id=operation_id,
             include_in_schema=include_in_schema,
             content_type=content_type,
+            name=name,
         )
 
     def head(
@@ -475,10 +472,10 @@ class APIRouter(routing.Router):
         description: str = None,
         response_description: str = "Successful Response",
         deprecated: bool = None,
-        name: str = None,
         operation_id: str = None,
         include_in_schema: bool = True,
         content_type: Type[Response] = JSONResponse,
+        name: str = None,
     ) -> Callable:
         return self.api_route(
             path=path,
@@ -489,11 +486,11 @@ class APIRouter(routing.Router):
             description=description,
             response_description=response_description,
             deprecated=deprecated,
-            name=name,
             methods=["HEAD"],
             operation_id=operation_id,
             include_in_schema=include_in_schema,
             content_type=content_type,
+            name=name,
         )
 
     def patch(
@@ -507,10 +504,10 @@ class APIRouter(routing.Router):
         description: str = None,
         response_description: str = "Successful Response",
         deprecated: bool = None,
-        name: str = None,
         operation_id: str = None,
         include_in_schema: bool = True,
         content_type: Type[Response] = JSONResponse,
+        name: str = None,
     ) -> Callable:
         return self.api_route(
             path=path,
@@ -521,11 +518,11 @@ class APIRouter(routing.Router):
             description=description,
             response_description=response_description,
             deprecated=deprecated,
-            name=name,
             methods=["PATCH"],
             operation_id=operation_id,
             include_in_schema=include_in_schema,
             content_type=content_type,
+            name=name,
         )
 
     def trace(
@@ -539,10 +536,10 @@ class APIRouter(routing.Router):
         description: str = None,
         response_description: str = "Successful Response",
         deprecated: bool = None,
-        name: str = None,
         operation_id: str = None,
         include_in_schema: bool = True,
         content_type: Type[Response] = JSONResponse,
+        name: str = None,
     ) -> Callable:
         return self.api_route(
             path=path,
@@ -553,9 +550,9 @@ class APIRouter(routing.Router):
             description=description,
             response_description=response_description,
             deprecated=deprecated,
-            name=name,
             methods=["TRACE"],
             operation_id=operation_id,
             include_in_schema=include_in_schema,
             content_type=content_type,
+            name=name,
         )
